@@ -60,7 +60,7 @@ class UR3Arm(robot_arms.RobotArm):
 
     @property
     def location(self) -> Location:
-        return Location.from_matrix(self.pose.array)
+        return Location.from_matrix(self.pose.array).convert_m_to_mm()
 
     @property
     def joint_positions(self) -> List[float]:
